<template>
  <div id="searchFormTable" class="searchwrapper" style="background:white;">
    <!-- 输出查询表单HTML -->
    <div class="mint-tab-container">
      <div class="mint-tab-container-wrap">
        <div class="mint-tab-container-item">
            <div class="formTable">
              <div class="searchDivCon" id="searchFormPanel" style="background:white;"> 
                <component name="searchform" :is="form(formdata)"></component>
              </div>
            </div>
        </div>
      </div>
    </div>
    <div class="row" v-show="searchBtnShow(formdata) && !isView">
      <div class="col-xs-12 text-center bottomBtn">
        <mt-button type="primary" width="100px" plain @click="reset" style="margin-right:10px;">{{$t('reset')}}</mt-button>
        <mt-button type="primary" @click="onSearchClick">{{$t('query')}}</mt-button>
      </div>
    </div>
    <div class="row" v-show="isView">
      <div class="bottomBtn-isview">
        <div class="rest-btn" @click="reset">{{$t('reset')}}</div>
        <div class="search-btn" @click="onSearchClick(isView)">{{$t('query')}}</div>
      </div>
    </div>
  </div>
</template>

<script>
import API from "@/api.js";
export default {
  name: "form-searchform",
  props: ["appId", "viewId","isView","openParams"],
  created: function() {
    this.initSearchForm({
      appId: this.appId,
      viewId: this.viewId
    });
  },

  data: function() {
    return {
      formdata: undefined
    };
  },

  methods: {
    getAllFields() {
      return this.formdata.fields;
    },
    form(data) {
      let mobileTmpl = "";
      if (data) {
        if (data && data.fields) {
          //手机端逻辑，不能根据模板，而只能根据field模拟一个模板
          data.fields.forEach(field => {
            let fieldTag = "";
            switch (field.formField) {
              case "InputField":
                fieldTag = "o-input";
                break;
              case "TextareaField":
                fieldTag = "o-textarea";
                break;
              case "RadioField":
                fieldTag = "o-radio";
                break;
              case "SelectField":
                fieldTag = "o-select";
                break;
              case "ImageUploadField":
                fieldTag = "o-image-upload";
                break;
              case "AttachmentUploadField":
                fieldTag = "o-file-upload";
                break;
              case "DateField":
                fieldTag = "o-date-picker";
                break;
              case "IncludeField":
                fieldTag = "o-include";
                break;
              case "CheckboxField":
                fieldTag = "o-checkbox";
                break;
              case "MapField":
                fieldTag = "o-map";
                break;
              case "QRCodeField":
                fieldTag = "o-qrcode";
                break;
              case "CalctextField":
                fieldTag = "o-calctext";
                break;
              case "UserField":
                fieldTag = "o-user-select";
                break;
              case "DepartmentField":
                fieldTag = "o-dept-select";
                break;
              case "TreeDepartmentField":
                fieldTag = "o-dept-tree-select"
                break;
              default:
                break;
            }
            if (fieldTag != "")
              mobileTmpl += `<${fieldTag} id='${field.id}'></${fieldTag}>`;
          });
        }

        return {
          methods: {
            findField(id) {
              for (let i = 0; i < data.fields.length; i++) {
                let fld = data.fields[i];
                if (id == fld.id) return fld;
              }
              return null;
            },
            getAllFields: this.getAllFields,
          },
          template: "<div>" + mobileTmpl + "</div>"
        };
      } else
        return {
          template: "<div></div>"
        };
    },

    initSearchForm({ appId, viewId }) {
      let urlParams = this.openParams.urlParams; //跳转按钮携带的参数
      let obj = {};
      if(urlParams) {
        let fp = urlParams.replace(/^(\s|&)+|(\s|&)+$/g, '');
        let list = fp.split("&");
        for (let i = 0; i < list.length; i++) {
          let p = list[i].split("=");
          if(p[1]) {
            obj[p[0]] = p[1];
          }
        }
      }

      API.getSearchFormTemplate(appId, viewId, obj, {
        onSucess: response => {
          if (response.data.data) {
            let fd = response.data.data;
            fd.formId = response.data.data.fields[0].formId; //可能不行，但没时间，先这样
            fd.docId = response.data.data.fields[0].docId;
            this.formdata = fd;
          }
        }
      });
    },

    refresh(fId) {
      let fieldId = '';
      if(fId.id) {
        fieldId = fId.id;
      }else {
        fieldId = fId;
      }
      //刷新方法
      let fd = this.buildFormData();
      let data = {
        document: fd,
        formId: this.formdata.formId,
        docId: fd.id,
        parentId: "",
        templateForm: "",
        viewId: "",
        applicationId: fd.applicationId,
        id: fd.id
      };
      this.$api.refreshForm(fieldId, data, {
        onSucess: response => {
          let fields = response.data.data;
          let keys = Object.keys(fields);
          keys.forEach(key => {
            let field = fields[key];
            this.formdata.fields.forEach((f, i) => {
              if (field.id == f.id) {
                this.formdata.fields[i].value = field.value; //只能更新value，而不能简单做对象替换，field.value绑定在组件v-model上，如果直接替换只是数组内存指针简单变更
                this.formdata.fields[i].options = field.options;
                this.formdata.fields[i].tabs = field.tabs;
                //如果为选择类型field，则options也要在这里替换.....
                this.formdata.fields[i].displayType = field.displayType;
                this.formdata.fields[i].data = field.data;
                if(this.formdata.fields[i].formField == "IncludeField") {
                  this.formdata.fields[i].isRefresh = parseInt(Math.random()*100+1)+new Date();
                }
                else if(field.formField == "DepartmentField") { //这个会把部门选择框的值去除掉，后果未知，先这样
                  if(this.formdata.fields[i].value && this.formdata.fields[i].options.length <= 0) {
                    this.formdata.fields[i].value = '';
                    this.formdata.fields[i].option = '';
                  }
                }
              }else if(f.tabs && f.tabs.length>0) {
                for(let z=0; z<f.tabs.length; z++) {
                  if(f.tabs[z].fields && f.tabs[z].fields.length > 0) {
                    for(let j=0; j<f.tabs[z].fields.length; j++) {
                      if(field.divId == f.tabs[z].fields[j].divId) {
                        //this.formdata.fields[i].tabs[z].fields[j] = field;
                        if(this.formdata.fields[i].tabs[z].fields[j].formField == "IncludeField") {
                          this.formdata.fields[i].tabs[z].fields[j].name = this.$t('monthlyPlan')
                          this.formdata.fields[i].tabs[z].fields[j].isRefresh = parseInt(Math.random()*100+1)+new Date();
                        }
                        this.formdata.fields[i].tabs[z].fields[j].value = field.value;
                        this.formdata.fields[i].tabs[z].fields[j].options = field.options;
                        this.formdata.fields[i].tabs[z].fields[j].tabs = field.tabs;
                        this.formdata.fields[i].tabs[z].fields[j].displayType = field.displayType;

                      }
                    }
                  }
                }
              }
            });
          });
        }
      });
      // echo(event, result)
    },

    searchBtnShow(data) {
      return data && data.template && data.template.length > 0;
    },

    onSearchClick() {
      let data = this.buildSearchData();
      data.appId = this.appId;
      data.viewId = this.viewId;
      this.$emit("onSearch",data);
    },
    
    reset() {
      let fields = this.formdata.fields;
      fields.forEach(item => {
        item.value = "";
        if(item.impressionVal) {
          item.impressionVal = '';
        }
      });
    },
    
    buildSearchData() {
      let data = {};
      if (this.formdata && this.formdata.fields)
        for (let i = 0; i < this.formdata.fields.length; i++) {
          let fld = this.formdata.fields[i];
          data[fld.name] = fld.value;
        }
      return data;
    },

    buildFormData() {
      let items = {};
      // 判断如果没有值就不执行
      if(this.formdata.fields){
        const loopOpe = fields => {
          for (let i = 0; i < fields.length; i++) {
            let fld = fields[i];
            if (
              fld.name &&
              fld.value != undefined &&
              fld.formField != "ButtonField" && 
              fld.displayType != undefined
            ) {
              if(fld.textType =="hidden" && fld.value) {
                items[fld.name] = fld.value;
              }else if(fld.textType !="hidden"){
                items[fld.name] = fld.value;
              }
            }
            if(fld.tabs && fld.tabs.length>0) {
              fld.tabs.forEach(tab => {
                if(tab.fields) {
                  loopOpe(tab.fields);
                }
              })
            }
          }
        };
        loopOpe(this.formdata.fields)
      }
      return {
        applicationId: this.openParams.appId,
        formId: this.formdata.formId,
        id: this.formdata.docId,
        items: items,
        parentId: "",
        sign: "",
        subDocuments: [],
        versions: "0"
      };
    },
  }
};
</script>
<style lang="scss" scoped>
.searchwrapper{
  width:100%;
  height: 100%; 
  overflow:auto;
  background-color: white;
  .mint-tab-container {
    width:100%;
    height: calc(100% - 46px);
    overflow: auto;
  }
  .formTable{
      height: 100%;
      .tree-dept-select{
        .dept-tree{
          .dept-tree-select{
            margin-left: 10px;
            padding: 0;
            .icon {
                display:flex;
                flex-direction: row;
                align-items: center;
                color:#26a2ff;
                height: 54px;
                width:250px;
                font-size:32px; 
                .dept-name {
                  font-size:14px;
                  color:#000000;
                  margin-left:10px;
                  width:250px;
                  height: 30px;
                  line-height: 30px;
                  display: inline-block;
                }
            }

            .tree-height{
                height: 54px;
                line-height: 54px;
                display:inline-block;
                .more {
                    display:inline-block;
                    width:20px; 
                    height:20px;
                    line-height:20px;
                    border-radius: 2px;
                    text-align:center;
                    color:#888888;
                    font-size:12px;
                    background:#f4f6f6;
                }
            }
            .tree-name {
                width:32px;
                height: 54px;
                line-height: 54px;
                display:inline-block;
                border:1px solid red;
            }
            .mint-checklist-label{
              padding: 0 6px 0 0;
              float: left;
            }
            .icon-open{
              width: 20px;
              float: right;
              
            }
          }
        }
      }
  }
}

.row {
  width: 100%;
  text-align: right;
  padding:5px 10px 5px 0;
  box-sizing: border-box;
  background:#fff;
  border-top:1px solid rgba(0,0,0,.09);
  .mint-button--normal {
    display: inline-block;
    padding: 0 26px;
  }
  .mint-button {
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    font-size: 15px;
    height: 35px;
    outline: 0;
    overflow: hidden;
    position: relative;
    text-align: center;
  }
  #searchBtn{
    background: #497bec;
    color: #fff;
  }
}
// .bottomBtn{
//   position: absolute;
//   bottom: 0;
//   width: 100%;
//   text-align: right;
//   padding:5px 10px 5px 0;
//   box-sizing: border-box;
//   background:#fff;
//   border-top:1px solid rgba(0,0,0,.09);
//   .mint-button--normal {
//     display: inline-block;
//     padding: 0 26px;
//   }
//   .mint-button {
//     -webkit-appearance: none;
//     -moz-appearance: none;
//     appearance: none;
//     font-size: 15px;
//     height: 35px;
//     outline: 0;
//     overflow: hidden;
//     position: relative;
//     text-align: center;
//   }
//   #searchBtn{
//     background: #497bec;
//     color: #fff;
//   }
// }
#restBtn,#searchBtn{
  width: 92px;
  height: 38px;
  border: none;
  background: #fff;
  border: 1px solid #497bec;
  margin: 5px;
  font-size: 16px;
  color: #497bec;
  line-height: 22px;
  text-align: center;
  border-radius: 4px;
}
.displayn{
  height:100%;
  .searchDivCon{
    height: calc(100% - 59px);
    overflow:scroll;
  }
}
.bottomBtn-isview{
  position: absolute;
  bottom: 0;
  width: 100%;
  text-align: right;
  box-sizing: border-box;
  background:#fff;
  border-top:1px solid rgba(0,0,0,.09);
  height: 38px;
  display: -webkit-flex;
  display: flex;
  justify-content: space-between;
  &>div {
    width: 50%;
    height:38px;
    line-height: 38px;
    text-align: center;
  }
  .rest-btn {
    background: #EFEFF4;
    font-size:16px;
    font-family:PingFangSC-Regular,PingFang SC;
    font-weight:400;
    color:rgba(38,162,255,1);
  }
  .search-btn {
    background:#26A2FF;
    font-size:16px;
    font-family:PingFangSC-Regular,PingFang SC;
    font-weight:400;
    color:rgba(255,255,255,1);
  }
}
    
</style>